@@ -16,20 +16,22 @@ from reno import loader
 
 def report_cmd(args, conf):
     "Generates a release notes report"
-    ldr = loader.Loader(conf)
     encoding = conf.options['encoding']
-    if args.version:
-        versions = args.version
-    else:
-        versions = ldr.versions
-    text = formatter.format_report(
-        ldr,
-        conf,
-        versions,
-        title=args.title,
-        show_source=args.show_source,
-        branch=args.branch,
-    )
+
+    with loader.Loader(conf) as ldr:
+        if args.version:
+            versions = args.version
+        else:
+            versions = ldr.versions
+        text = formatter.format_report(
+            ldr,
+            conf,
+            versions,
+            title=args.title,
+            show_source=args.show_source,
+            branch=args.branch,
+        )
+
     if args.output:
         with open(args.output, 'w', encoding=encoding) as f:
             f.write(text)
